==> iframework-gwtpx-0.3-sources.jar: pro/redsoft/iframework/client/xml/TestBean.java <==
/**
 * Copyright 2013 REDSOFT.PRO
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package pro.redsoft.iframework.client.xml;

/**
 * TestBean.
 * 
 * @author Alex N. Oreshkevich
 */
public class TestBean {

  // /*
  // * Core2 Class Open Library for Google Web Toolkit v2.1
  // *
  // * Copyright (C) 2010 Alexander Oreshkewitsh
  // *
  // * This program is free software; you can redistribute it and/or modify
  // * it under the terms of the GNU General Public License as published by
  // * the Free Software Foundation; either version 2 of the License, or
  // * (at your option) any later version.
  // *
  // * This program is distributed in the hope that it will be useful,
  // * but WITHOUT ANY WARRANTY; without even the implied warranty of
  // * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  // * GNU General Public License for more details.
  // *
  // * You should have received a copy of the GNU General Public License
  // * along with this program; if not, write to the Free Software
  // * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  // *
  // * Author: Alexander Oreshkewitsh (aka Neo)
  // *
  // * Second Editor: Ignatovich Sergej
  // *
  // * E-Mail: neo.bsuir@gmail.com
  // *
  // */
  //
  // package ru.intertrust.cmj.client.turbo;
  //
  // import java.util.ArrayList;
  //
  // import by.ipps.egr.client.logic.StandardClassDescriptor;
  // import by.ipps.egr.client.modelr.basic.Address;
  //
  // import com.google.gwt.user.client.rpc.IsSerializable;
  //
  //
  // /**
  // *
  // * @author Neo
  // *
  // */
  // @StandardClassDescriptor(author = "Neo", date = "12/10/10", currentRevision = 1, reviewers = { "" },
  // lastModified = "", lastModifiedBy = "")
  // public class TestBean extends RBean implements IsSerializable {
  //
  // RField<Integer> nXvalue = new RField<Integer>("fieldName", 12, DataTypes.tField, this);
  //
  // RField<Address> address1;
  // RField<Address> address2;
  //
  // RField<ArrayList<Address>> listAdr;
  //
  // public TestBean() {
  //
  // address1 = createField("adres", new Address(), DataTypes.tObject);
  //
  // address2 = createField("adres2", new Address(), DataTypes.tObject);
  //
  // listAdr = createField("MyListAddress", new ArrayList<Address>(), DataTypes.tListObject);
  //
  // }
  //
  // public Integer getnXvalue() {
  // return nXvalue.getValue();
  // }
  //
  // public void setnXvalue(Integer nXvalue) {
  // setField(this.nXvalue, nXvalue);
  // }
  //
  // /*
  //
  //
  //
  //
  //
  // *//**
  // * @return the listAdr
  // */
  // /*
  // * public ArrayList<RField<Address>> getListAdr() { return listAdr.getValue(); }
  // *//**
  // * @param listAdr
  // * the listAdr to set
  // */
  // /*
  // * public void setListAdr(ArrayList<RField<Address>> listAdr) { setField(this.listAdr , listAdr); }
  // *//**
  // * @return the address1
  // */
  // /*
  // * public Address getAddress1() { return address1.getValue(); }
  // *//**
  // * @param address1
  // * the address1 to set
  // */
  // /*
  // * public void setAddress1(Address address1) { setField(this.address1, address1); }
  // */
  //
  // public ArrayList<Address> getListAdr() {
  // return listAdr.getValue();
  // }
  //
  // public void setListAdr(ArrayList<Address> listAdr) {
  // setField(this.listAdr, listAdr);
  // }
  //
  // public Address getAddress1() {
  // return address1.getValue();
  // }
  //
  // public void setAddress1(Address address1) {
  // setField(this.address1, address1);
  // }
  //
  // @Override
  // public CreatableBean newInstance() {
  // return new TestBean();
  // }
  // }
}

==> iframework-gwtpx-0.4.0-sources.jar: pro/redsoft/iframework/client/xml/TestBean.java <==
/*
The MIT License (MIT)

Copyright (c) 2013 - 2014  REDSOFT.PRO

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/
package pro.redsoft.iframework.client.xml;

/**
 * TestBean.
 * 
 * @author Alex N. Oreshkevich
 */
public class TestBean {

  // /*
  // * Core2 Class Open Library for Google Web Toolkit v2.1
  // *
  // * Copyright (C) 2010 Alexander Oreshkewitsh
  // *
  // * This program is free software; you can redistribute it and/or modify
  // * it under the terms of the GNU General Public License as published by
  // * the Free Software Foundation; either version 2 of the License, or
  // * (at your option) any later version.
  // *
  // * This program is distributed in the hope that it will be useful,
  // * but WITHOUT ANY WARRANTY; without even the implied warranty of
  // * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  // * GNU General Public License for more details.
  // *
  // * You should have received a copy of the GNU General Public License
  // * along with this program; if not, write to the Free Software
  // * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  // *
  // * Author: Alexander Oreshkewitsh (aka Neo)
  // *
  // * Second Editor: Ignatovich Sergej
  // *
  // * E-Mail: neo.bsuir@gmail.com
  // *
  // */
  //
  // package ru.intertrust.cmj.client.turbo;
  //
  // import java.util.ArrayList;
  //
  // import by.ipps.egr.client.logic.StandardClassDescriptor;
  // import by.ipps.egr.client.modelr.basic.Address;
  //
  // import com.google.gwt.user.client.rpc.IsSerializable;
  //
  //
  // /**
  // *
  // * @author Neo
  // *
  // */
  // @StandardClassDescriptor(author = "Neo", date = "12/10/10", currentRevision = 1, reviewers = { "" },
  // lastModified = "", lastModifiedBy = "")
  // public class TestBean extends RBean implements IsSerializable {
  //
  // RField<Integer> nXvalue = new RField<Integer>("fieldName", 12, DataTypes.tField, this);
  //
  // RField<Address> address1;
  // RField<Address> address2;
  //
  // RField<ArrayList<Address>> listAdr;
  //
  // public TestBean() {
  //
  // address1 = createField("adres", new Address(), DataTypes.tObject);
  //
  // address2 = createField("adres2", new Address(), DataTypes.tObject);
  //
  // listAdr = createField("MyListAddress", new ArrayList<Address>(), DataTypes.tListObject);
  //
  // }
  //
  // public Integer getnXvalue() {
  // return nXvalue.getValue();
  // }
  //
  // public void setnXvalue(Integer nXvalue) {
  // setField(this.nXvalue, nXvalue);
  // }
  //
  // /*
  //
  //
  //
  //
  //
  // *//**
  // * @return the listAdr
  // */
  // /*
  // * public ArrayList<RField<Address>> getListAdr() { return listAdr.getValue(); }
  // *//**
  // * @param listAdr
  // * the listAdr to set
  // */
  // /*
  // * public void setListAdr(ArrayList<RField<Address>> listAdr) { setField(this.listAdr , listAdr); }
  // *//**
  // * @return the address1
  // */
  // /*
  // * public Address getAddress1() { return address1.getValue(); }
  // *//**
  // * @param address1
  // * the address1 to set
  // */
  // /*
  // * public void setAddress1(Address address1) { setField(this.address1, address1); }
  // */
  //
  // public ArrayList<Address> getListAdr() {
  // return listAdr.getValue();
  // }
  //
  // public void setListAdr(ArrayList<Address> listAdr) {
  // setField(this.listAdr, listAdr);
  // }
  //
  // public Address getAddress1() {
  // return address1.getValue();
  // }
  //
  // public void setAddress1(Address address1) {
  // setField(this.address1, address1);
  // }
  //
  // @Override
  // public CreatableBean newInstance() {
  // return new TestBean();
  // }
  // }
}
